#ifndef _LOG_H_
#define _LOG_H_

#include "config.h"

void Aprint(char *format, ... );
void Aflushlog(void);

#endif /* _LOG_H_ */
